====================================
bluesky_runs_catalog_table_model
====================================

.. automodule:: gemviz.bluesky_runs_catalog_table_model
    :members:
    :private-members:
